From 72f134d4b07941ff8e0949783b25c8c995c7db59 Mon Sep 17 00:00:00 2001
From: unknown <ldecicco@usgs.gov>
Date: Tue, 2 Dec 2014 15:55:51 -0600
Subject: [PATCH] Updates to help files.

---
 R/constructNWISURL.r                          |   4 +--
 R/importRDB1.r                                |   8 ++---
 R/importWaterML1.r                            |   2 +-
 R/importWaterML2.r                            |  10 +++----
 R/readNWISpCode.r                             |   3 +-
 R/readNWISqw.r                                |  28 ++++++++++--------
 R/readNWISsite.r                              |   2 +-
 R/readNWISunit.r                              |   4 +--
 inst/doc/dataRetrieval.pdf                    | Bin 297151 -> 297150 bytes
 man/constructNWISURL.Rd                       |   4 +--
 man/importRDB1.Rd                             |   8 ++---
 man/importWaterML1.Rd                         |   2 +-
 man/importWaterML2.Rd                         |   2 +-
 man/readNWISpCode.Rd                          |   3 +-
 man/readNWISqw.Rd                             |  22 ++++++++------
 man/readNWISsite.Rd                           |   2 +-
 vignettes/figure/getNWIStemperaturePlot-1.pdf | Bin 6597 -> 6597 bytes
 17 files changed, 55 insertions(+), 49 deletions(-)

diff --git a/R/constructNWISURL.r b/R/constructNWISURL.r
index 36508f02..ca19cb45 100644
--- a/R/constructNWISURL.r
+++ b/R/constructNWISURL.r
@@ -16,7 +16,7 @@
 #' @param format string, can be "tsv" or "xml", and is only applicable for daily and unit value requests.  "tsv" returns results faster, but there is a possiblitiy that an incomplete file is returned without warning. XML is slower, 
 #' but will offer a warning if the file was incomplete (for example, if there was a momentary problem with the internet connection). It is possible to safely use the "tsv" option, 
 #' but the user must carefully check the results to see if the data returns matches what is expected. The default is therefore "xml". 
-#' @param expanded logical defaults to FALSE. If TRUE, retrieves additional information, only applicable for qw data.
+#' @param expanded logical defaults to \code{TRUE}. If \code{TRUE}, retrieves additional information, only applicable for qw data.
 #' @param ratingType can be "base", "corr", or "exsa". Only applies to rating curve data.
 #' @keywords data import USGS web service
 #' @return url string
@@ -43,7 +43,7 @@
 #' url_meas <- constructNWISURL(siteNumber, service="meas")
 #'            }
 constructNWISURL <- function(siteNumber,parameterCd="00060",startDate="",endDate="",
-                             service,statCd="00003", format="xml",expanded=FALSE,
+                             service,statCd="00003", format="xml",expanded=TRUE,
                              ratingType="base"){
 
   service <- match.arg(service, c("dv","uv","iv","qw","gwlevels","rating","peak","meas"))
diff --git a/R/importRDB1.r b/R/importRDB1.r
index c39db0e9..b07f2328 100644
--- a/R/importRDB1.r
+++ b/R/importRDB1.r
@@ -6,20 +6,20 @@
 #' recommended to use the RDB format for importing multi-site data. 
 #'
 #' @param obs_url character containing the url for the retrieval
-#' @param asDateTime logical, if TRUE returns date and time as POSIXct, if FALSE, Date
-#' @param qw logical, if TRUE parses as water quality data (where dates/times are in start and end times)
+#' @param asDateTime logical, if \code{TRUE} returns date and time as POSIXct, if \code{FALSE}, Date
+#' @param qw logical, if \code{TRUE} parses as water quality data (where dates/times are in start and end times)
 #' @param tz character to set timezone attribute of datetime. Default is an empty quote, which converts the 
 #' datetimes to UTC (properly accounting for daylight savings times based on the data's provided tz_cd column).
 #' Possible values to provide are "America/New_York","America/Chicago", "America/Denver","America/Los_Angeles",
 #' "America/Anchorage","America/Honolulu","America/Jamaica","America/Managua","America/Phoenix", and "America/Metlakatla"
-#' @param convertType logical, defaults to TRUE. If TRUE, the function will convert the data to dates, datetimes,
+#' @param convertType logical, defaults to \code{TRUE}. If \code{TRUE}, the function will convert the data to dates, datetimes,
 #' numerics based on a standard algorithm. If false, everything is returned as a character
 #' @return A data frame with the following columns:
 #' \tabular{lll}{
 #' Name \tab Type \tab Description \cr
 #' agency_cd \tab character \tab The NWIS code for the agency reporting the data\cr
 #' site_no \tab character \tab The USGS site number \cr
-#' datetime \tab POSIXct \tab The date and time of the value converted to UTC (if asDateTime = TRUE), \cr 
+#' datetime \tab POSIXct \tab The date and time of the value converted to UTC (if asDateTime = \code{TRUE}), \cr 
 #' \tab character \tab or raw character string (if asDateTime = FALSE) \cr
 #' tz_cd \tab character \tab The time zone code for datetime \cr
 #' code \tab character \tab Any codes that qualify the corresponding value\cr
diff --git a/R/importWaterML1.r b/R/importWaterML1.r
index 673b70a6..0bd52435 100644
--- a/R/importWaterML1.r
+++ b/R/importWaterML1.r
@@ -4,7 +4,7 @@
 #' NWIS site, parameter code, statistic, startdate and enddate. 
 #'
 #' @param obs_url character containing the url for the retrieval
-#' @param asDateTime logical, if TRUE returns date and time as POSIXct, if FALSE, Date
+#' @param asDateTime logical, if \code{TRUE} returns date and time as POSIXct, if \code{FALSE}, Date
 #' @param tz character to set timezone attribute of datetime. Default is an empty quote, which converts the 
 #' datetimes to UTC (properly accounting for daylight savings times based on the data's provided tz_cd column).
 #' Possible values to provide are "America/New_York","America/Chicago", "America/Denver","America/Los_Angeles",
diff --git a/R/importWaterML2.r b/R/importWaterML2.r
index 8879d771..3d4c5baf 100644
--- a/R/importWaterML2.r
+++ b/R/importWaterML2.r
@@ -4,7 +4,7 @@
 #' but the general functionality is correct.
 #'
 #' @param obs_url character containing the url for the retrieval
-#' @param asDateTime logical, if TRUE returns date and time as POSIXct, if FALSE, Date
+#' @param asDateTime logical, if \code{TRUE} returns date and time as POSIXct, if \code{FALSE}, Date
 #' @param tz character to set timezone attribute of datetime. Default is an empty quote, which converts the 
 #' datetimes to UTC (properly accounting for daylight savings times based on the data's provided tz_cd column).
 #' Possible values to provide are "America/New_York","America/Chicago", "America/Denver","America/Los_Angeles",
@@ -42,7 +42,9 @@
 #' }
 importWaterML2 <- function(obs_url, asDateTime=FALSE, tz=""){
   
-  if(url.exists(obs_url)){
+  if(file.exists(obs_url)){
+    doc <- xmlTreeParse(obs_url, getDTD = FALSE, useInternalNodes = TRUE)
+  } else {
     doc = tryCatch({
       h <- basicHeaderGatherer()
       returnedDoc <- getURL(obs_url, headerfunction = h$update)
@@ -62,9 +64,7 @@ importWaterML2 <- function(obs_url, asDateTime=FALSE, tz=""){
       message(paste("URL does not seem to exist:", obs_url))
       message(e)
       return(NA)
-    }) 
-  } else {
-    doc <- xmlTreeParse(obs_url, getDTD = FALSE, useInternalNodes = TRUE)
+    })
   }
   
   if(tz != ""){
diff --git a/R/readNWISpCode.r b/R/readNWISpCode.r
index 416fa19f..24e8fcdf 100644
--- a/R/readNWISpCode.r
+++ b/R/readNWISpCode.r
@@ -3,7 +3,7 @@
 #' Imports data from NWIS about meaured parameter based on user-supplied parameter code.
 #' This function gets the data from here: \url{http://nwis.waterdata.usgs.gov/nwis/pmcodes}
 #'
-#' @param parameterCd character of USGS parameter codes.  This is usually an 5 digit number.
+#' @param parameterCd character of USGS parameter codes (or multiple parameter codes).  This is usually an 5 digit number.
 #' @keywords data import USGS web service
 #' @return parameterData data frame with all information from the USGS about the particular parameter.
 #' 
@@ -19,7 +19,6 @@
 #' 
 #' @export
 #' @examples
-#' # These examples require an internet connection to run
 #' paramINFO <- readNWISpCode(c('01075','00060','00931'))
 readNWISpCode <- function(parameterCd){
  
diff --git a/R/readNWISsite.r b/R/readNWISsite.r
index aa69f3df..cd29868a 100644
--- a/R/readNWISsite.r
+++ b/R/readNWISsite.r
@@ -2,7 +2,7 @@
 #'
 #' Imports data from USGS site file site. This function gets data from here: \url{http://waterservices.usgs.gov/}
 #'
-#' @param siteNumbers character USGS site number.  This is usually an 8 digit number
+#' @param siteNumbers character USGS site number (or multiple sites).  This is usually an 8 digit number
 #' @keywords data import USGS web service
 #' @return A data frame with at least the following columns:
 #' \tabular{lll}{
diff --git a/R/readNWISunit.r b/R/readNWISunit.r
index 5f27695e..99203ea4 100644
--- a/R/readNWISunit.r
+++ b/R/readNWISunit.r
@@ -107,14 +107,14 @@ readNWISuv <- function (siteNumbers,parameterCd,startDate="",endDate="", tz=""){
 readNWISpeak <- function (siteNumbers,startDate="",endDate=""){  
   
   # Doesn't seem to be a peak xml service
-  url <- constructNWISURL(siteNumber,NA,startDate,endDate,"peak")
+  url <- constructNWISURL(siteNumbers,NA,startDate,endDate,"peak")
   
   data <- importRDB1(url, asDateTime=FALSE)
   
   data$peak_dt <- as.Date(data$peak_dt)
   data$gage_ht <- as.numeric(data$gage_ht)
   
-  siteInfo <- readNWISsite(siteNumber)
+  siteInfo <- readNWISsite(siteNumbers)
   
   attr(data, "siteInfo") <- siteInfo
   attr(data, "variableInfo") <- NULL
diff --git a/inst/doc/dataRetrieval.pdf b/inst/doc/dataRetrieval.pdf
index 7a64272609718a7c11616097f9a2b1b33e2ecd77..b4c14374c26f784d7b7c4c382b1baf63407846dd 100644
GIT binary patch
delta 3566
zcmai1c~lff8h2o3(E(QxK_f)Q1Mxz-tGcVJky}6qi3;&ZJQ9ZhUI;FNf=F6ITwPsM
zLZHz^S;4phMi2y)tdM|!#^{P5xFTWA5=cT2#S0J2))?U})qm`~H?O9@qrPALzN307
zQbv`hj4E)-n7~7p!_&0RZ$*aq7@|XUQ+-?j!*VQO0Q*W;v>>B;l?tSK#ZD`7dmL#h
zT~KA4ef-(K?rb{q+~2}&{)O1jlCOkxW&g!{=s!9FhTlAFnb2{5cg=ja#u2(3DaExf
zTJ1`fcFLXknarg^&1RVNWN7<Evy7fK6{jY)IyUKTI%giS%rPJ47j8H)WJ=k=Kk+a-
zIW(1-aV>fJw@boK*8SAB{EIv5k2iS4{uc4i@CM2Ej5fV?Zf=0#uVs4vwC~<Ss-DU$
z!TR{PWUI|Cd;YWdhFjhCqRFRHpLJCZ4SMKPY#yMuD4N^TS9bN*yzcHB(=D)FPIJd&
zE+hKXx7Kg>+6-?ineyjnI{%Kk*du3-_Knk;{qYZ0U#HejwVV8@ReA4H;hv|*^IJn;
z%bRgm<n%zPtHIW}E3f8_VOJedRe($5#^X(+6G!hhzwcQPIO6h{gG*Z6YQJ2UR&uOm
zpX1p>)=!7$POzA9F=Tw&j}gt2V!zp7S61*KWYXkq0j5g>Q*xKBd(+XjuiCuAFZ-Cd
zU)SffWy!Lj50WY!obsZB155sXDc`=WAUUFB(YssI$KL6Dr&=nhw1Uasmz0mUnHLn)
zY`u8n{Y!Du*_FkQYfHiliWg3;TV?vCpUrRb#ZwW>pXa!*UeUeEY+1Ws*w-!owRdlO
z+ja$?_tJb=Z}`G)nCDlao5rPRH!iyOk$z@JAX~v72t61eKS<hgKgb8ig*7iu{$<(m
z^ErBx3w<$>arI>@b{0x$_SyM5t<}|$W+_4z(>rPAgM1GQk0+0s46!R7xmdvWFYWp;
zue1C{Oy=oR@j35xUr$UP>6)~w59XDo_sSXGmhGMRTuWU}^wX^eom|ErUCr%Dx;#@5
z{iD-DQkyU9!z<rNvCud6RvoxGIxl|vbq`lJ*37K0b(<-4{W+#f`svq)zn++V6Q({W
ze;T}RLXRQ*!O8b`c~~?Ta?9TqXV3n{&HIDcZMSVL;<Kk%e}gR-1{qLad{ct7-*0P3
zdF}b^?C<sFV|olP8a>ZlS=fB7_4GYPHS0*Qr|aIzpP%2=KdH6RzO3JKAWRt9d(Hmk
z+ON`+-s|p|l2TP)pSi2zk(4OMm;Ku!_4&ym*0;Y)YiRvcYI`@z<#4(_^lDSV-Po0r
z^BPK=8~i^HnAH&&b8Zi6Uwu38;;l$?O|V0|A?|M(j+jY!XKb#eJTG{`?wAqIlcx^#
zwmWk|cHil*o4CFDtgohc>e<D;I~?3&oaW7%bGk;uF8g@Gx~l5T8qJ|GQK6>t{sez}
zSTJ|feNX?wxco)n#g1ui`}St-U~4w4^cs3}!85;y(=$`I&wm*jIPQF&5FQ<W*sf+v
z#LEznsxSX8x4G(OV_4CTZOqGX&Dg|SJ99kDabkYooV4;|jw<n9#rpkYZ^`$yDyyO+
zeJeDk_OT(QFHBUnChAH}W{goWdY7|CMZPBFYg+28QRf*nJOnJ3Tf@}jU;i{&qs~`B
zxp0kop$f<*YsmuTptb4+CX6U&86SDM$N0#JviG`I+E0v&Apc-oSQ)H;W%JQ`V#A8^
zb>kzHCvG4MBS#q*C|4R6ERPC*B@8w$NG=Q~9$1u3Hj+nP4%(=mZ4Gpc@uQ2-X^ktu
z5CcKZGODmbB``qlF{&7a3IQy8N2tXySQHgXp6BFGB8Z=$P;m&!KNwX=p@Je)3L@3B
zHEs$wR>TT)0J4h603lJ%jaEC-h*`uz#L4Z^>TVTV+8Cprp_-<kf`x<_BP;(y4{-#g
z)3>Uhm?-%H0!F21o7&z~1xuGEs3T3MQT`0#S)`D0BH-k^JJgO692|~80wYqyFbHAg
z7CaDG+82oeMF@j1&nWCL5?;rZ`pbYpA}3NfSx)2uB_kV(9F++ogFHur5dcGFk=S84
z7>q<NSdko=b`~M8U_oRADq%)|;@}O*ege-?pjmPZmLD90<yir+5+&qB%uy*JhM3+E
zV3y?-8$!&|01?Ll#eNV8{S2;r-Gu}p3n>;@1O<T(f*^(z)x-{qbPxnZUQSF>TS+WU
z5aLL(sdFRpn$wS|9}<yaDuc#e;HbnH8;hY}lA*%F-+iTlRw6jbhYn1prQ$q1LpM7K
z!egbcqQqE4l0WEh62lmUkjf0eq}3EB<~c=H5s6Ee6GG&LkUj`P%7X|DD=Fv~2D-1m
z`B>6GPyq&Go|XwbMhY2XL|TRgQair`9O!V8Op&Ia@W=Fzf_^YWh7@y^j9)<20wC|j
z3>BD6WS$+&mc$sxG(+VWaAYddMZ*DxZa%<qWZn#>8gM*IjS&WrM&kzMo!o4Qj24mV
zaFTaGS3jv%02K8BAxl*{z&wv>Fqjv3g)c91{dUs8J&Tm6F@p4T1{iTlfC$lDPwX&5
z6(Ny{^dyh~CUZ_<C=g;PT1nB+g+zQYJ=uv&ME$25I2>m1;JlL;3(O)x=SW?r7%1{i
zZUqSC@w?Stt9|FNBKfZ+3dqaH$IC|q-o7j^GQe9Dpr0TBcb)71HCd%|ch_!?Hbh0o
UMumoH2@b?yt%HN_LO<<)0n8l+sQ>@~

delta 3267
zcmai02~bp57OjR4rZ9yHvIL9*Rv>Kh|NGnf3L+x71Vuz}L$O_2MD}Tv0<p!2I6;DK
zi%%vRgAf%rWDK;4r3BGL2BL)-f{=lLL);jZ#svl9%=?yF@qMbMtA4$H_r7=Tx#!;d
zyD#c(YV<Z|eD}KoTH<L>E5EtPYi6jmYh6B`F&WSd#{e4O2m8*>+ka)bVOoaQ*??!s
z=DNG8+7UO!vvpl@{Y8$M`*xZH=P&BpX4>YC&bVIebY{xLfooY~3Q*?B3Db^G+)((U
zMoKvKi(gA@pnA{Rk+(ILkH$3WN727u-?BX9V)$u;&o4{-CoXWX*>&^Md{vm1{dc@3
z)VaZ39sQMa)ZP<~i%Xm8tLD@-hn4GkU$%eQdQ6ueXXjH`xUl$=W4a-JRlYrM-klqg
z>=nj4dEC~H{jvOb*5MbL*)bkZf6X0JcK5IG4*T~wY6`mt(+^hZJAOM6<(L8&7_UEA
zPv46v@;=h*>vT17?)y)J_FgMB`L7Qi<i}c%d*6Ml$I%El>tm12rc+6sIa{7psWjhB
z>HC|XZ>g@WTwKw%sDQOO5T3B3SbOr<unJEz&(RLIa#og(-{%KTe3$k4vY)*YXP^Ht
zJcak}b6yzi7`?mR->ad$dS>so7N}L<sSlm?WWVLf!){R(Hzv;$2J#)Y6ok(H%lM#y
zW&b&Ty6gwb+)tK9-@AM`A>0rfcvbD(o>21lhd#`umdej`iMbvcrwfVM0Y1CS%BsDO
zwcRp2ewp%Z{DZ>8)|DF$%|CqJa%q9jOF#Yc_HUj=W`AGZao+lLV?pEA^F^Pxf14|`
zUCI2^YUoJa9LZ+u#)eML&93dMP7A~0Yo)8UY;b7+#gp!gcyR0Mohf~d)#Xmj6=7MC
z25RSEPe<R8bfeW;op)epY|vQu1FqI?$urcwGZ){E)j4i?*i%v0TYW#>QFC$6s6V1x
zvQP9(UA?@2!G(^m&7EB{EJqEli%#}6`7ya}jV-BZ=Sw5+^*sX1wEoj;<Hn9aOOn#|
z-u0??HzLE$?X24edrq42Tq`}J`=6KTGBQ_LTMyJcwbW$X=xNh6wccxu*mP!{`<?8^
zSH=Z**WJ9mq{dq3SiN@rH%HPoZv1D~_8)qmoD&_Nh0gWbmg@Fp*`<Vm{?mgm#}_=j
zy16iG=FAHQ`$^q(&rju~eQ~I|q-J%O+APNZ%GM0~+@Jf~4G#-_#||B}bNwmFrMDz-
zsA;3`hzlLp=ep$`JsLPl*P}D{>(|zP;NHJP<#n#uyS&EpzgN$8YbW~}{&Ao}-EKNJ
zE4n-}_E-@tj=5HPKg}+&vG&{|ebsOFR+r~A*7Z$e!c$fboS_#^oTR^eV06#;6|?4#
z-VWm;{Iaczrp<W%S!%vjd_+oluj-S{_m}RD*|Dl%<f_x}1>e|_A6PJw^Xt}FPMR>d
zcdBM(Vdt%!y=xw?C|UDd6`48CAw;!$SIfC=qo*HyQgAnFs>h3cLk)+y%tgsJ?>?I>
z?RxO9q53uMhRwxM#=Oc?KWQ53)kCdTv{}{2NS%F(S?pk*SN801v$Rf~$~4lk8I>$G
zw>^9Ck7X9-&Yf|_K{J)J8Fi!i(56?8JYNeHe$4P=ZuGUFPO2>cL(>xK&`{%Fe^src
zDpVY*Tt|hgSfq->3x^`&sCi}#jY{OLfK2k1r%}-QS6;omK-48K05S2e&g8`7Gk``-
z@|Huc8}P!QRC(c0t-MHROu{RpT3$p{nSgIdG*Ttvt$-pDsVR1>3oU<Kl3c9h6+jjO
zh)QIaq;QEei%hbMQMd#kp`av6a*!~XjPz$np68K13EzVX7bl3QOLmD07b`JFCYhRI
z5umunNKnBJus{(R2qKNjwUh@|rb$cLs(AFfmU^TD#^!X&TP5qiiLzCu!w4K}^xQ=C
zn_&@MGx0^y$Y)X$%vGE*Dw|3+_aqdc1)dQUHckROda#x9&~fi(M`K<Rkufa@Pzk{U
z5s-HU2@;vo0_17MIVgy)<66I|FD*!%#GsNK$~Hhj7h)e73$i><+C)G@WRf9>kPIh@
zjDniP@`_X?T4Yhsw&5T|o+FqsJpSPo-etk?j0gbI%MgUP*ab-l02zi?K(LTuQP;2#
ztRNCvU=|EVB*zG>C<=)Al(N+kGGQ0ilOQdy5>HGVZZ(=Ab;LGN5eonHASnqP178ov
z+Y)0yz=@~{a|$3b#?#HP#4ur=EUVzjv$%6zw_^xpNFFMW<BlLx#bu;XstiG73?OcQ
z1uV}g>Lc)&FRGOx6cGghC<GUW5mLl6fX3twmk5MB$wK6zps)$FBq6m7LFNcWiIfiD
z!o8WgH$#VQ0)A0f4g&%3ze$>i2w2>~#0X%UMDs|s12-C3R1VM_p%36VC=vPqj%Qe+
z(SX2lJke;_rg*>Ll7Tl3`L@w;Hvzz+63i)p7;pf29+L4PFOtoV&q*AQOfm#X4GJvz
zN&`^f-q3g}E))coM?rZQf>Z$)lN><+MLfpu_A0h<oP_i;1X&9x;#3sJB|%|>G-Oa0
zhVUf11V9LAvStwCp+g_;q=JHZ8n=EZoDRk5TnHD$&tP%P;NT!G1d5^bbZ)AP|NlFJ
SN_J9q?@3l4eH0QNYV|*aD%-38

diff --git a/man/constructNWISURL.Rd b/man/constructNWISURL.Rd
index 8f39fcb7..100f4eaa 100644
--- a/man/constructNWISURL.Rd
+++ b/man/constructNWISURL.Rd
@@ -5,7 +5,7 @@
 \usage{
 constructNWISURL(siteNumber, parameterCd = "00060", startDate = "",
   endDate = "", service, statCd = "00003", format = "xml",
-  expanded = FALSE, ratingType = "base")
+  expanded = TRUE, ratingType = "base")
 }
 \arguments{
 \item{siteNumber}{string or vector of strings USGS site number.  This is usually an 8 digit number}
@@ -27,7 +27,7 @@ retrieval for the latest possible record.}
 but will offer a warning if the file was incomplete (for example, if there was a momentary problem with the internet connection). It is possible to safely use the "tsv" option,
 but the user must carefully check the results to see if the data returns matches what is expected. The default is therefore "xml".}
 
-\item{expanded}{logical defaults to FALSE. If TRUE, retrieves additional information, only applicable for qw data.}
+\item{expanded}{logical defaults to \code{TRUE}. If \code{TRUE}, retrieves additional information, only applicable for qw data.}
 
 \item{ratingType}{can be "base", "corr", or "exsa". Only applies to rating curve data.}
 }
diff --git a/man/importRDB1.Rd b/man/importRDB1.Rd
index 0812b312..5726875b 100644
--- a/man/importRDB1.Rd
+++ b/man/importRDB1.Rd
@@ -9,11 +9,11 @@ importRDB1(obs_url, asDateTime = FALSE, qw = FALSE, convertType = TRUE,
 \arguments{
 \item{obs_url}{character containing the url for the retrieval}
 
-\item{asDateTime}{logical, if TRUE returns date and time as POSIXct, if FALSE, Date}
+\item{asDateTime}{logical, if \code{TRUE} returns date and time as POSIXct, if \code{FALSE}, Date}
 
-\item{qw}{logical, if TRUE parses as water quality data (where dates/times are in start and end times)}
+\item{qw}{logical, if \code{TRUE} parses as water quality data (where dates/times are in start and end times)}
 
-\item{convertType}{logical, defaults to TRUE. If TRUE, the function will convert the data to dates, datetimes,
+\item{convertType}{logical, defaults to \code{TRUE}. If \code{TRUE}, the function will convert the data to dates, datetimes,
 numerics based on a standard algorithm. If false, everything is returned as a character}
 
 \item{tz}{character to set timezone attribute of datetime. Default is an empty quote, which converts the
@@ -27,7 +27,7 @@ A data frame with the following columns:
 Name \tab Type \tab Description \cr
 agency_cd \tab character \tab The NWIS code for the agency reporting the data\cr
 site_no \tab character \tab The USGS site number \cr
-datetime \tab POSIXct \tab The date and time of the value converted to UTC (if asDateTime = TRUE), \cr
+datetime \tab POSIXct \tab The date and time of the value converted to UTC (if asDateTime = \code{TRUE}), \cr
 \tab character \tab or raw character string (if asDateTime = FALSE) \cr
 tz_cd \tab character \tab The time zone code for datetime \cr
 code \tab character \tab Any codes that qualify the corresponding value\cr
diff --git a/man/importWaterML1.Rd b/man/importWaterML1.Rd
index 6ca6214e..8f4d2a59 100644
--- a/man/importWaterML1.Rd
+++ b/man/importWaterML1.Rd
@@ -8,7 +8,7 @@ importWaterML1(obs_url, asDateTime = FALSE, tz = "")
 \arguments{
 \item{obs_url}{character containing the url for the retrieval}
 
-\item{asDateTime}{logical, if TRUE returns date and time as POSIXct, if FALSE, Date}
+\item{asDateTime}{logical, if \code{TRUE} returns date and time as POSIXct, if \code{FALSE}, Date}
 
 \item{tz}{character to set timezone attribute of datetime. Default is an empty quote, which converts the
 datetimes to UTC (properly accounting for daylight savings times based on the data's provided tz_cd column).
diff --git a/man/importWaterML2.Rd b/man/importWaterML2.Rd
index 9fca77fb..44c9bf6e 100644
--- a/man/importWaterML2.Rd
+++ b/man/importWaterML2.Rd
@@ -8,7 +8,7 @@ importWaterML2(obs_url, asDateTime = FALSE, tz = "")
 \arguments{
 \item{obs_url}{character containing the url for the retrieval}
 
-\item{asDateTime}{logical, if TRUE returns date and time as POSIXct, if FALSE, Date}
+\item{asDateTime}{logical, if \code{TRUE} returns date and time as POSIXct, if \code{FALSE}, Date}
 
 \item{tz}{character to set timezone attribute of datetime. Default is an empty quote, which converts the
 datetimes to UTC (properly accounting for daylight savings times based on the data's provided tz_cd column).
diff --git a/man/readNWISpCode.Rd b/man/readNWISpCode.Rd
index 4025c6b5..a5c44f97 100644
--- a/man/readNWISpCode.Rd
+++ b/man/readNWISpCode.Rd
@@ -6,7 +6,7 @@
 readNWISpCode(parameterCd)
 }
 \arguments{
-\item{parameterCd}{character of USGS parameter codes.  This is usually an 5 digit number.}
+\item{parameterCd}{character of USGS parameter codes (or multiple parameter codes).  This is usually an 5 digit number.}
 }
 \value{
 parameterData data frame with all information from the USGS about the particular parameter.
@@ -26,7 +26,6 @@ Imports data from NWIS about meaured parameter based on user-supplied parameter
 This function gets the data from here: \url{http://nwis.waterdata.usgs.gov/nwis/pmcodes}
 }
 \examples{
-# These examples require an internet connection to run
 paramINFO <- readNWISpCode(c('01075','00060','00931'))
 }
 \keyword{USGS}
diff --git a/man/readNWISqw.Rd b/man/readNWISqw.Rd
index b63ee7b7..116e38cf 100644
--- a/man/readNWISqw.Rd
+++ b/man/readNWISqw.Rd
@@ -3,13 +3,13 @@
 \alias{readNWISqw}
 \title{Raw Data Import for USGS NWIS QW Data}
 \usage{
-readNWISqw(siteNumbers, pCodes, startDate = "", endDate = "",
+readNWISqw(siteNumbers, parameterCd, startDate = "", endDate = "",
   expanded = TRUE, reshape = FALSE, tz = "")
 }
 \arguments{
 \item{siteNumbers}{character of USGS site numbers.  This is usually an 8 digit number}
 
-\item{pCodes}{character of USGS parameter code(s).  This is usually an 5 digit number.}
+\item{parameterCd}{character of USGS parameter code(s).  This is usually an 5 digit number.}
 
 \item{startDate}{character starting date for data retrieval in the form YYYY-MM-DD. Default is "" which indicates
 retrieval for the earliest possible record.}
@@ -17,12 +17,14 @@ retrieval for the earliest possible record.}
 \item{endDate}{character ending date for data retrieval in the form YYYY-MM-DD. Default is "" which indicates
 retrieval for the latest possible record.}
 
-\item{expanded}{logical defaults to TRUE. If TRUE, retrieves additional information. Expanded data includes
+\item{expanded}{logical defaults to \code{TRUE}. If \code{TRUE}, retrieves additional information. Expanded data includes
 remark_cd (remark code), result_va (result value), val_qual_tx (result value qualifier code), meth_cd (method code),
-dqi_cd (data-quality indicator code), rpt_lev_va (reporting level), and rpt_lev_cd (reporting level type).}
+dqi_cd (data-quality indicator code), rpt_lev_va (reporting level), and rpt_lev_cd (reporting level type). If \code{FALSE},
+only returns remark_cd (remark code) and result_va (result value). Expanded = \code{FALSE} will not give
+sufficient information for unbiased statistical analysis.}
 
-\item{reshape}{logical. Will reshape the data to a wide format if TRUE (default is FALSE). This is only
-available for 'expanded' data.}
+\item{reshape}{logical, reshape the data. If \code{TRUE}, then return a wide data frame with all water-quality in a single row for each sample.
+If \code{FALSE} (default), then return a long data frame with each water-quality result in a single row.}
 
 \item{tz}{character to set timezone attribute of datetime. Default is an empty quote, which converts the
 datetimes to UTC (properly accounting for daylight savings times based on the data's provided tz_cd column).
@@ -48,6 +50,8 @@ Name \tab Type \tab Description \cr
 url \tab character \tab The url used to generate the data \cr
 queryTime \tab POSIXct \tab The time the data was returned \cr
 comment \tab character \tab Header comments from the RDB file \cr
+siteInfo \tab data.frame \tab A data frame containing information on the requested sites \cr
+variableInfo \tab data.frame \tab A data frame containing information on the requested parameters \cr
 }
 }
 \description{
@@ -59,10 +63,10 @@ A list of statistic codes can be found here: \url{http://nwis.waterdata.usgs.gov
 siteNumbers <- c('04024430','04024000')
 startDate <- '2010-01-01'
 endDate <- ''
-pCodes <- c('34247','30234','32104','34220')
+parameterCd <- c('34247','30234','32104','34220')
 
-rawNWISqwData <- readNWISqw(siteNumbers,pCodes,startDate,endDate)
-rawNWISqwDataReshaped <- readNWISqw(siteNumbers,pCodes,
+rawNWISqwData <- readNWISqw(siteNumbers,parameterCd,startDate,endDate)
+rawNWISqwDataReshaped <- readNWISqw(siteNumbers,parameterCd,
           startDate,endDate,reshape=TRUE)
 }
 \seealso{
diff --git a/man/readNWISsite.Rd b/man/readNWISsite.Rd
index e740573e..8802bcd8 100644
--- a/man/readNWISsite.Rd
+++ b/man/readNWISsite.Rd
@@ -6,7 +6,7 @@
 readNWISsite(siteNumbers)
 }
 \arguments{
-\item{siteNumbers}{character USGS site number.  This is usually an 8 digit number}
+\item{siteNumbers}{character USGS site number (or multiple sites).  This is usually an 8 digit number}
 }
 \value{
 A data frame with at least the following columns:
diff --git a/R/readNWISqw.r b/R/readNWISqw.r
index 9e6229a5..20b86a2f 100644
--- a/R/readNWISqw.r
+++ b/R/readNWISqw.r
@@ -5,16 +5,18 @@
 #' A list of statistic codes can be found here: \url{http://nwis.waterdata.usgs.gov/nwis/help/?read_file=stat&format=table}
 #'
 #' @param siteNumbers character of USGS site numbers.  This is usually an 8 digit number
 #' @param pCodes character of USGS parameter code(s).  This is usually an 5 digit number.
 #' @param startDate character starting date for data retrieval in the form YYYY-MM-DD. Default is "" which indicates
 #' retrieval for the earliest possible record.
 #' @param endDate character ending date for data retrieval in the form YYYY-MM-DD. Default is "" which indicates
 #' retrieval for the latest possible record.
-#' @param expanded logical defaults to TRUE. If TRUE, retrieves additional information. Expanded data includes
+#' @param expanded logical defaults to \code{TRUE}. If \code{TRUE}, retrieves additional information. Expanded data includes
 #' remark_cd (remark code), result_va (result value), val_qual_tx (result value qualifier code), meth_cd (method code),
-#' dqi_cd (data-quality indicator code), rpt_lev_va (reporting level), and rpt_lev_cd (reporting level type).
-#' @param reshape logical. Will reshape the data to a wide format if TRUE (default is FALSE). This is only
-#' available for 'expanded' data.
+#' dqi_cd (data-quality indicator code), rpt_lev_va (reporting level), and rpt_lev_cd (reporting level type). If \code{FALSE},
+#' only returns remark_cd (remark code) and result_va (result value). Expanded = \code{FALSE} will not give
+#' sufficient information for unbiased statistical analysis.
+#' @param reshape logical, reshape the data. If \code{TRUE}, then return a wide data frame with all water-quality in a single row for each sample. 
+#' If \code{FALSE} (default), then return a long data frame with each water-quality result in a single row.
 #' @param tz character to set timezone attribute of datetime. Default is an empty quote, which converts the 
 #' datetimes to UTC (properly accounting for daylight savings times based on the data's provided tz_cd column).
 #' Possible values to provide are "America/New_York","America/Chicago", "America/Denver","America/Los_Angeles",
@@ -38,6 +40,8 @@
 #' url \tab character \tab The url used to generate the data \cr
 #' queryTime \tab POSIXct \tab The time the data was returned \cr
 #' comment \tab character \tab Header comments from the RDB file \cr
+#' siteInfo \tab data.frame \tab A data frame containing information on the requested sites \cr
+#' variableInfo \tab data.frame \tab A data frame containing information on the requested parameters \cr
 #' }
 #' @export
 #' @import reshape2
@@ -47,16 +51,16 @@
 #' siteNumbers <- c('04024430','04024000')
 #' startDate <- '2010-01-01'
 #' endDate <- ''
-#' pCodes <- c('34247','30234','32104','34220')
+#' parameterCd <- c('34247','30234','32104','34220')
 #' 
-#' rawNWISqwData <- readNWISqw(siteNumbers,pCodes,startDate,endDate)
-#' rawNWISqwDataReshaped <- readNWISqw(siteNumbers,pCodes,
+#' rawNWISqwData <- readNWISqw(siteNumbers,parameterCd,startDate,endDate)
+#' rawNWISqwDataReshaped <- readNWISqw(siteNumbers,parameterCd,
 #'           startDate,endDate,reshape=TRUE)
 #'           
-readNWISqw <- function (siteNumbers,pCodes,startDate="",endDate="",
+readNWISqw <- function (siteNumbers,parameterCd,startDate="",endDate="",
                         expanded=TRUE,reshape=FALSE,tz=""){  
   
-  url <- constructNWISURL(siteNumbers,pCodes,startDate,endDate,"qw",expanded=expanded)
+  url <- constructNWISURL(siteNumbers,parameterCd,startDate,endDate,"qw",expanded=expanded)
   
   data <- importRDB1(url,asDateTime=TRUE, qw=TRUE, tz = tz)
   originalHeader <- comment(data)
@@ -70,7 +74,7 @@ readNWISqw <- function (siteNumbers,pCodes,startDate="",endDate="",
     wideDF <- dcast(longDF, ... ~ variable + parm_cd )
     wideDF[,grep("_va_",names(wideDF))] <- sapply(wideDF[,grep("_va_",names(wideDF))], function(x) as.numeric(x))
     
-    groupByPCode <- as.vector(sapply(pCodes, function(x) grep(x, names(wideDF)) ))
+    groupByPCode <- as.vector(sapply(parameterCd, function(x) grep(x, names(wideDF)) ))
     data <- wideDF[,c(1:length(columnsToMelt)-1,groupByPCode)]
     comment(data) <- originalHeader
     
@@ -81,7 +85,7 @@ readNWISqw <- function (siteNumbers,pCodes,startDate="",endDate="",
   }
   
   siteInfo <- readNWISsite(siteNumbers)
-  varInfo <- readNWISpCode(pCodes)
+  varInfo <- readNWISpCode(parameterCd)
   
   attr(data, "siteInfo") <- siteInfo
   attr(data, "variableInfo") <- varInfo
@@ -5,16 +5,18 @@
 #'
 #' @param siteNumbers character of USGS site numbers.  This is usually an 8 digit number
-#' @param pCodes character of USGS parameter code(s).  This is usually an 5 digit number.
+#' @param parameterCd character of USGS parameter code(s).  This is usually an 5 digit number.
 #' @param startDate character starting date for data retrieval in the form YYYY-MM-DD. Default is "" which indicates
 #' retrieval for the earliest possible record.
diff --git a/vignettes/figure/getNWIStemperaturePlot-1.pdf b/vignettes/figure/getNWIStemperaturePlot-1.pdf
index 690d55aeb71ae546305160ead49a81e76e8f87f4..579e593554b281fe8a4012fa060bc46b8f112444 100644
GIT binary patch
delta 25
ccmX?VeAIY?6|1SSp^3#rdvOS3V|11z0A`T~MF0Q*

delta 25
ccmX?VeAIY?6|0efrK!P0dvOS3V|11z0A?x&I{*Lx

-- 
GitLab